@@ -1,13 +1,14 @@
 package CPAN::YACSmoke::Plugin::NNTP;
+
 use strict;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # -------------------------------------
 
 =head1 NAME
 
-CPAN::YACSmoke::Plugin::NNTP - NNTP list plugin for Yet Another CPAN Smoke Tester
+CPAN::YACSmoke::Plugin::NNTP - NNTP plugin for Yet Another CPAN Smoke Tester
 
 =head1 SYNOPSIS
 
@@ -176,6 +177,14 @@ For additional information, see the documentation for these modules:
   Test::Reporter
   CPAN::YACSmoke
 
+=head1 DSLIP
+
+  b - Beta testing
+  d - Developer
+  p - Perl-only
+  O - Object oriented
+  p - Standard-Perl: user may choose between GPL and Artistic
+
 =head1 AUTHOR
 
   Barbie, <barbie@cpan.org>
